@@ -8,6 +8,7 @@ from django.template.context import Context
 from django.utils.safestring import mark_safe
 from django.utils.html import escape,format_html
 from django.utils.text import Truncator
+from django.core.cache import cache, get_cache
 
 from xadmin.views.list import EMPTY_CHANGELIST_VALUE
 import datetime
@@ -199,7 +200,7 @@ class ChoicesFieldListFilter(ListFieldFilter):
 @manager.register
 class TextFieldListFilter(FieldFilter):
     template = 'xadmin/filters/char.html'
-    lookup_formats = {'search': '%s__contains'}
+    lookup_formats = {'in': '%s__in','search': '%s__contains'}
 
     @classmethod
     def test(cls, field, request, params, model, admin_view, field_path):
@@ -322,7 +323,7 @@ class RelatedFieldSearchFilter(FieldFilter):
         else:
             rel_name = other_model._meta.pk.name
 
-        self.lookup_formats = {'exact': '%%s__%s__exact' % rel_name}
+        self.lookup_formats = {'in': '%%s__%s__in' % rel_name,'exact': '%%s__%s__exact' % rel_name}
         super(RelatedFieldSearchFilter, self).__init__(
             field, request, params, model, model_admin, field_path)
 
@@ -369,7 +370,7 @@ class RelatedFieldListFilter(ListFieldFilter):
         else:
             rel_name = other_model._meta.pk.name
 
-        self.lookup_formats = {'exact': '%%s__%s__exact' %
+        self.lookup_formats = {'in': '%%s__%s__in' % rel_name,'exact': '%%s__%s__exact' %
                                rel_name, 'isnull': '%s__isnull'}
         self.lookup_choices = field.get_choices(include_blank=False)
         super(RelatedFieldListFilter, self).__init__(
@@ -419,6 +420,80 @@ class RelatedFieldListFilter(ListFieldFilter):
                 'display': EMPTY_CHANGELIST_VALUE,
             }
 
+@manager.register
+class MultiSelectFieldListFilter(ListFieldFilter):
+    """ Delegates the filter to the default filter and ors the results of each
+     
+    Lists the distinct values of each field as a checkbox
+    Uses the default spec for each 
+     
+    """
+    template = 'xadmin/filters/checklist.html'
+    lookup_formats = {'in': '%s__in'}
+    cache_config = {'enabled':False,'key':'quickfilter_%s','timeout':3600,'cache':'default'}
+ 
+    @classmethod
+    def test(cls, field, request, params, model, admin_view, field_path):
+        return True
+ 
+    def get_cached_choices(self):
+        if not self.cache_config['enabled']:
+            return None
+        c = get_cache(self.cache_config['cache'])
+        return c.get(self.cache_config['key']%self.field_path)
+    
+    def set_cached_choices(self,choices):
+        if not self.cache_config['enabled']:
+            return
+        c = get_cache(self.cache_config['cache'])
+        return c.set(self.cache_config['key']%self.field_path,choices)
+    
+    def __init__(self, field, request, params, model, model_admin, field_path,field_order_by=None,field_limit=None,sort_key=None,cache_config=None):
+        super(MultiSelectFieldListFilter,self).__init__(field, request, params, model, model_admin, field_path)
+        
+        # Check for it in the cachce
+        if cache_config is not None and type(cache_config)==dict:
+            self.cache_config.update(cache_config)
+        
+        if self.cache_config['enabled']:
+            self.field_path = field_path
+            choices = self.get_cached_choices()
+            if choices:
+                self.lookup_choices = choices
+                return
+            
+        # Else rebuild it
+        queryset = self.admin_view.queryset().exclude(**{"%s__isnull"%field_path:True}).values_list(field_path, flat=True).distinct() 
+        #queryset = self.admin_view.queryset().distinct(field_path).exclude(**{"%s__isnull"%field_path:True})
+        
+        if field_order_by is not None:
+            # Do a subquery to order the distinct set
+            queryset = self.admin_view.queryset().filter(id__in=queryset).order_by(field_order_by)
+            
+        if field_limit is not None and type(field_limit)==int and queryset.count()>field_limit:
+            queryset = queryset[:field_limit]
+        
+        self.lookup_choices = [str(it) for it in queryset.values_list(field_path,flat=True) if str(it).strip()!=""]
+        if sort_key is not None:
+            self.lookup_choices = sorted(self.lookup_choices,key=sort_key)
+        
+        if self.cache_config['enabled']:
+            self.set_cached_choices(self.lookup_choices) 
+
+    def choices(self):
+        self.lookup_in_val = (type(self.lookup_in_val) in (tuple,list)) and self.lookup_in_val or list(self.lookup_in_val)
+        yield {
+            'selected': len(self.lookup_in_val) == 0,
+            'query_string': self.query_string({},[self.lookup_in_name]),
+            'display': _('All'),
+        }
+        for val in self.lookup_choices:
+            yield {
+                'selected': smart_unicode(val) in self.lookup_in_val,
+                'query_string': self.query_string({self.lookup_in_name: ",".join([val]+self.lookup_in_val),}),
+                'remove_query_string': self.query_string({self.lookup_in_name: ",".join([v for v in self.lookup_in_val if v != val]),}),
+                'display': val,
+            }
 
 @manager.register
 class AllValuesFieldListFilter(ListFieldFilter):
@@ -468,4 +543,4 @@ class AllValuesFieldListFilter(ListFieldFilter):
                 'query_string': self.query_string({self.lookup_isnull_name: 'True'},
                                                   [self.lookup_exact_name]),
                 'display': EMPTY_CHANGELIST_VALUE,
-            }
+            }
\ No newline at end of file
