@@ -2,7 +2,7 @@
 PLUGINS = ('actions', 'filters', 'bookmark', 'export', 'layout', 'refresh', 'sortable', 'details',
     'editable', 'relate', 'chart', 'ajax', 'relfield', 'inline', 'topnav', 'portal', 'quickform',
     'wizard', 'images', 'auth', 'multiselect', 'themes', 'aggregation', 'mobile', 'passwords',
-    'sitemenu', 'language', 'comments')
+    'sitemenu', 'language', 'comments','quickfilter')
 
 
 def register_builtin_plugins(site):
