@@ -48,7 +48,7 @@ class DetailsPlugin(BaseAdminPlugin):
                                 args=(getattr(rel_obj, opts.pk.attname),))
                         else:
                             edit_url = ''
-                        item.btns.append('<a data-res-uri="%s" data-edit-uri="%s" class="details-handler" rel="tooltip" title="%s"><i class="icon-info-sign"></i></a>'
+                        item.btns.append('<a data-res-uri="%s" data-edit-uri="%s" class="details-handler" rel="tooltip" title="%s"><i class="fa fa-info-sign"></i></a>'
                                          % (item_res_uri, edit_url, _(u'Details of %s') % str(rel_obj)))
                 except NoReverseMatch:
                     pass
