@@ -13,6 +13,7 @@ from django.utils.safestring import mark_safe
 from django.utils.text import capfirst
 from django.utils.translation import ugettext as _
 from xadmin.layout import Field, render_field
+from xadmin.plugins.inline import Inline
 from xadmin.plugins.actions import BaseActionView
 from xadmin.plugins.inline import InlineModelAdmin
 from xadmin.sites import site
@@ -162,7 +163,7 @@ class ReversionPlugin(BaseAdminPlugin):
     # Block Views
     def block_top_toolbar(self, context, nodes):
         recoverlist_url = self.admin_view.model_admin_url('recoverlist')
-        nodes.append(mark_safe('<div class="btn-group"><a class="btn btn-default btn-sm" href="%s"><i class="icon-trash"></i> %s</a></div>' % (recoverlist_url, _(u"Recover"))))
+        nodes.append(mark_safe('<div class="btn-group"><a class="btn btn-default btn-sm" href="%s"><i class="fa fa-trash-o"></i> %s</a></div>' % (recoverlist_url, _(u"Recover"))))
 
     def block_nav_toggles(self, context, nodes):
         obj = getattr(
@@ -170,7 +171,7 @@ class ReversionPlugin(BaseAdminPlugin):
         if obj:
             revisionlist_url = self.admin_view.model_admin_url(
                 'revisionlist', quote(obj.pk))
-            nodes.append(mark_safe('<a href="%s" class="navbar-toggle pull-right"><i class="icon-time"></i></a>' % revisionlist_url))
+            nodes.append(mark_safe('<a href="%s" class="navbar-toggle pull-right"><i class="fa fa-time"></i></a>' % revisionlist_url))
 
     def block_nav_btns(self, context, nodes):
         obj = getattr(
@@ -178,7 +179,7 @@ class ReversionPlugin(BaseAdminPlugin):
         if obj:
             revisionlist_url = self.admin_view.model_admin_url(
                 'revisionlist', quote(obj.pk))
-            nodes.append(mark_safe('<a href="%s" class="btn btn-default"><i class="icon-time"></i> <span>%s</span></a>' % (revisionlist_url, _(u'History'))))
+            nodes.append(mark_safe('<a href="%s" class="btn btn-default"><i class="fa fa-time"></i> <span>%s</span></a>' % (revisionlist_url, _(u'History'))))
 
 
 class BaseReversionView(ModelAdminView):
@@ -621,14 +622,21 @@ class ActionRevisionPlugin(BaseAdminPlugin):
         return self.revision_context_manager.create_revision(manage_manually=False)(self.do_action_func(__))()
 
 
+class VersionInline(object):
+    model = Version
+    extra = 0
+    style = 'accordion'
+
 class ReversionAdmin(object):
-    model_icon = 'exchange'
+    model_icon = 'fa fa-exchange'
 
+    list_display = ('__str__', 'date_created', 'user', 'comment')
+    list_display_links = ('__str__',)
+
+    list_filter = ('date_created', 'user')
+    inlines = [VersionInline]
 
-class VersionAdmin(object):
-    model_icon = 'file'
 site.register(Revision, ReversionAdmin)
-site.register(Version, VersionAdmin)
 
 site.register_modelview(
     r'^recover/$', RecoverListView, name='%s_%s_recoverlist')
