@@ -27,7 +27,7 @@ def view_block(context, block_name, *args, **kwargs):
 
 @register.filter
 def admin_urlname(value, arg):
-    return 'admin:%s_%s_%s' % (value.app_label, value.module_name, arg)
+    return 'xadmin:%s_%s_%s' % (value.app_label, value.module_name, arg)
 
 static = register.simple_tag(static)
 
